==> JDFLibJ-2.1.4a.74-sources.jar: org/cip4/jdflib/jmf/JMFBuilderFactory.java <==
/*
 *
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2012 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */

package org.cip4.jdflib.jmf;

import java.util.HashMap;

/**
 * factory for statically getting JMFBuilders
 * 
 * @author Dr. Rainer Prosi, Heidelberger Druckmaschinen AG
 * 
 * June 20, 2009 split off from JMFFactory
 */
public class JMFBuilderFactory
{
	final private HashMap<Object, JMFBuilder> theBuilders;
	private static JMFBuilderFactory theSingleton = null;

	/**
	 * @param key 
	 * @param acknowledgeURL the acknowledgeURL to set
	 */
	public static void setAcknowledgeURL(final Object key, final String acknowledgeURL)
	{
		JMFBuilder b = getJMFBuilder(key);
		b.setAcknowledgeURL(acknowledgeURL);
	}

	/**
	 * set a senderID for agiven key value
	 * @param key the key for the map retrieval
	 * @param senderID the senderID to set
	 */
	public static void setSenderID(final Object key, final String senderID)
	{
		JMFBuilder b = getJMFBuilder(key);
		b.setSenderID(senderID);
	}

	/**
	 * get a JMFBuilder, create it if it has not yet been stored in the map
	 * @param key
	 * @return
	 */
	public static synchronized JMFBuilder getJMFBuilder(Object key)
	{
		if (theSingleton == null)
			theSingleton = new JMFBuilderFactory();
		return theSingleton.getBuilderForKey(key);
	}

	/**
	 * get a JMFBuilder, create it if it has not yet been stored in the map
	 * @param key
	 * @return
	 */
	private synchronized JMFBuilder getBuilderForKey(Object key)
	{
		if (key == null)
			key = JMFBuilderFactory.class;
		JMFBuilder b = theBuilders.get(key);
		if (b == null)
		{
			b = new JMFBuilder();
			theBuilders.put(key, b);
		}
		return b;
	}

	/**
	 * 
	 */
	private JMFBuilderFactory()
	{
		super();
		theBuilders = new HashMap<Object, JMFBuilder>();
	}
}

==> JDFLibJ-2.1.5.85-sources.jar: org/cip4/jdflib/jmf/JMFBuilderFactory.java <==
/*
 *
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2015 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */

package org.cip4.jdflib.jmf;

import java.util.HashMap;

/**
 * factory for statically getting JMFBuilders
 * 
 * @author Dr. Rainer Prosi, Heidelberger Druckmaschinen AG
 * 
 * June 20, 2009 split off from JMFFactory
 */
public class JMFBuilderFactory
{
	final private HashMap<Object, JMFBuilder> theBuilders;
	private static JMFBuilderFactory theSingleton = null;

	/**
	 * @param key 
	 * @param acknowledgeURL the acknowledgeURL to set
	 */
	public static void setAcknowledgeURL(final Object key, final String acknowledgeURL)
	{
		JMFBuilder b = getJMFBuilder(key);
		b.setAcknowledgeURL(acknowledgeURL);
	}

	/**
	 * set a senderID for a given key value
	 * @param key the key for the map retrieval
	 * @param senderID the senderID to set
	 */
	public static void setSenderID(final Object key, final String senderID)
	{
		JMFBuilder b = getJMFBuilder(key);
		b.setSenderID(senderID);
	}

	/**
	 * get a JMFBuilder, create it if it has not yet been stored in the map
	 * @param key
	 * @return
	 */
	public static synchronized JMFBuilder getJMFBuilder(Object key)
	{
		if (theSingleton == null)
			theSingleton = new JMFBuilderFactory();
		return theSingleton.getBuilderForKey(key);
	}

	/**
	 * get a JMFBuilder, create it if it has not yet been stored in the map
	 * new builders are cloned from the null builder, if one exists
	 * 
	 * @param key
	 * @return
	 */
	private synchronized JMFBuilder getBuilderForKey(Object key)
	{
		if (key == null)
			key = JMFBuilderFactory.class;

		JMFBuilder b = theBuilders.get(key);
		if (b == null)
		{
			b = theBuilders.get(JMFBuilderFactory.class);
			if (b != null)
			{
				b = b.clone();
			}
			else
			{
				b = new JMFBuilder();
			}
			theBuilders.put(key, b);
		}
		return b;
	}

	/**
	 * 
	 */
	private JMFBuilderFactory()
	{
		super();
		theBuilders = new HashMap<Object, JMFBuilder>();
	}

	@Override
	public String toString()
	{
		return "JMFBuilderFactory [theBuilders=" + theBuilders + "]";
	}
}
